@@ -42,8 +42,9 @@
 #' @examples knit_hooks$set(rgl = hook_rgl)
 #' ## then in code chunks, use the option rgl=TRUE
 hook_rgl = function(before, options, envir) {
+  library(rgl)
   ## after a chunk has been evaluated
-  if (before || !require('rgl') || rgl.cur() == 0) return()  # no active device
+  if (before || rgl.cur() == 0) return()  # no active device
   name = fig_path()
   par3d(windowRect = 100 + options$dpi * c(0, 0, options$fig.width, options$fig.height))
   Sys.sleep(.05) # need time to respond to window size change
