@@ -151,7 +151,7 @@ hook_plot_tex = function(x, options) {
   function(x, options) {
     x = gsub('\n*$', '', x)
     sprintf('\n\n{\\ttfamily\\noindent%s%s%s}',
-            color1, escape_latex(x, newlines = TRUE), color2)
+            color1, escape_latex(x, newlines = TRUE, spaces = TRUE), color2)
   }
 }
 
@@ -202,9 +202,9 @@ render_latex = function() {
         str_c('\\end{kframe}', x, '\\begin{kframe}')
       } else .verb.hook(x)
     },
-    warning = .color.block('\\textcolor{warningcolor}{', '}'),
-    message = .color.block('\\itshape\\textcolor{messagecolor}{', '}'),
-    error = .color.block('\\bfseries\\textcolor{errorcolor}{', '}'),
+    warning = .color.block('\\color{warningcolor}{', '}'),
+    message = .color.block('\\itshape\\color{messagecolor}{', '}'),
+    error = .color.block('\\bfseries\\color{errorcolor}{', '}'),
     inline = .inline.hook.tex, chunk = .chunk.hook.tex,
     plot = function(x, options) {
       ## escape plot environments from kframe
@@ -245,24 +245,32 @@ render_listings = function() {
 
 ## may add textile, and many other markup languages
 
-#' A document hook function to move code out of floating environments
+#' Some potentially useful document hooks
 #'
-#' This is a document hook to move code chunks out of LaTeX floating
-#' environments like \samp{figure} and \samp{table} when the chunks were
-#' actually written inside the floats.
+#' A document hook is a function to post-process the output document.
 #'
-#' This function is primarily designed for LyX: we often insert code chunks into
-#' floats to generate figures or tables, but in the final output we do not want
-#' the code to float with the environments, so we use regular expressions to
-#' find out the floating environments, extract the code chunks and move them
-#' out. To disable this behavior, use a comment \code{\% knitr_do_not_move} in
-#' the floating environment.
+#' \code{hook_movecode()} is a document hook to move code chunks out of LaTeX
+#' floating environments like \samp{figure} and \samp{table} when the chunks
+#' were actually written inside the floats. This function is primarily designed
+#' for LyX: we often insert code chunks into floats to generate figures or
+#' tables, but in the final output we do not want the code to float with the
+#' environments, so we use regular expressions to find out the floating
+#' environments, extract the code chunks and move them out. To disable this
+#' behavior, use a comment \code{\% knitr_do_not_move} in the floating
+#' environment.
+#'
+#' \code{hook_rjournal()} is a hook designed for the R Journal; it adds
+#' \samp{\\begin{article}} after \samp{\\begin{document}}, and
+#' \samp{\\end{article}} before \samp{\\end{document}}, because that is how the
+#' R Journal style works, although it is unusual.
+#' @rdname hook_document
 #' @param x a character string (the content of the whole document output)
 #' @return The post-processed document as a character string.
-#' @note This function is hackish. It assumes you to use the default output
-#'   hooks for LaTeX (not Sweave or listings), and every figure/table
-#'   environment must have a label.
+#' @note These functions are hackish. Also note \code{hook_movecode()} assumes
+#'   you to use the default output hooks for LaTeX (not Sweave or listings), and
+#'   every figure/table environment must have a label.
 #' @export
+#' @references \url{http://yihui.name/knitr/hooks}
 #' @examples \dontrun{knit_hooks$set(document = hook_movecode)}
 hook_movecode = function(x) {
   x = split_lines(x)
@@ -304,3 +312,11 @@ hook_movecode = function(x) {
   }), use.names = FALSE), collapse = '\n')
   .rm.empty.envir(res)
 }
+#' @rdname hook_document
+#' @export
+hook_rjournal = function(x) {
+  x = split_lines(x)
+  x = sub('^\\\\begin\\{document\\}$', '\\\\begin{document}\n\\\\begin{article}', x)
+  x = sub('^\\\\end\\{document\\}$', '\\\\end{article}\n\\\\end{document}', x)
+  x
+}
